==> RsCMPX_Base-4.0.180-py3-none-any.whl: RsCMPX_Base/Implementations/Configure/Tenvironment/Spath/Attenuation/Tx.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TxCls:
	"""Tx commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tx", core, parent)

	def set(self, name_signal_path: str, value: float) -> None:
		"""SCPI: [CONFigure]:TENVironment:SPATh:ATTenuation:TX \n
		Snippet: driver.configure.tenvironment.spath.attenuation.tx.set(name_signal_path = '1', value = 1.0) \n
		Assigns a frequency-independent correction value to the TX direction or RX direction of a signal path. The directions
		refer to the instrument (TX/RX of the instrument) . \n
			:param name_signal_path: Name of the signal path
			:param value: Attenuation
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('name_signal_path', name_signal_path, DataType.String), ArgSingle('value', value, DataType.Float))
		self._core.io.write(f'CONFigure:TENVironment:SPATh:ATTenuation:TX {param}'.rstrip())

	def get(self, name_signal_path: str) -> float:
		"""SCPI: [CONFigure]:TENVironment:SPATh:ATTenuation:TX \n
		Snippet: value: float = driver.configure.tenvironment.spath.attenuation.tx.get(name_signal_path = '1') \n
		Assigns a frequency-independent correction value to the TX direction or RX direction of a signal path. The directions
		refer to the instrument (TX/RX of the instrument) . \n
			:param name_signal_path: Name of the signal path
			:return: value: Attenuation"""
		param = Conversions.value_to_quoted_str(name_signal_path)
		response = self._core.io.query_str(f'CONFigure:TENVironment:SPATh:ATTenuation:TX? {param}')
		return Conversions.str_to_float(response)

==> RsCMPX_Base-5.0.60-py3-none-any.whl: RsCMPX_Base/Implementations/Configure/Tenvironment/Spath/Attenuation/Tx.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TxCls:
	"""Tx commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tx", core, parent)

	def set(self, name_signal_path: str, value: float) -> None:
		"""SCPI: [CONFigure]:TENVironment:SPATh:ATTenuation:TX \n
		Snippet: driver.configure.tenvironment.spath.attenuation.tx.set(name_signal_path = 'abc', value = 1.0) \n
		Assigns a frequency-independent correction value to the TX direction or RX direction of a connection. The directions
		refer to the instrument (TX/RX of the instrument) . \n
			:param name_signal_path: Name of the connection
			:param value: Attenuation
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('name_signal_path', name_signal_path, DataType.String), ArgSingle('value', value, DataType.Float))
		self._core.io.write(f'CONFigure:TENVironment:SPATh:ATTenuation:TX {param}'.rstrip())

	def get(self, name_signal_path: str) -> float:
		"""SCPI: [CONFigure]:TENVironment:SPATh:ATTenuation:TX \n
		Snippet: value: float = driver.configure.tenvironment.spath.attenuation.tx.get(name_signal_path = 'abc') \n
		Assigns a frequency-independent correction value to the TX direction or RX direction of a connection. The directions
		refer to the instrument (TX/RX of the instrument) . \n
			:param name_signal_path: Name of the connection
			:return: value: Attenuation"""
		param = Conversions.value_to_quoted_str(name_signal_path)
		response = self._core.io.query_str(f'CONFigure:TENVironment:SPATh:ATTenuation:TX? {param}')
		return Conversions.str_to_float(response)
